# ApplicationConfig

The generic list of configurations that will be passed to environment.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**authentication_config** | [**ApplicationAuthenticationConfig**](ApplicationAuthenticationConfig.md) |  | [optional] 
**oidc_config** | [**OIDCProxyConfig**](OIDCProxyConfig.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


